Hi all developers,

  I just cvs update Kaffe CVS, and I found it encountered compilation
errors while Kaffe was configured with the option --with-stats. Since
the CVS version of Kaffe had changed some internal data structure, so
taht I have to patch it as the attachment.

cheers,
Jim Huang
--- kaffe/kaffe/kaffevm/classPool.c     2003-09-22 23:31:24.000000000 +0800
+++ kaffe-fix/kaffe/kaffevm/classPool.c 2004-03-17 15:28:56.000000000 +0800
@@ -571,10 +571,10 @@
         */
        misc += SIZE_IFNONZERO(clazz);          /* myself */
        if (!CLASS_IS_PRIMITIVE(clazz)) {
                /* For primitives, dtable is -1 and methods is the
                 * class of the corresponding array
                 */
-               misc += SIZE_IFNONZERO(clazz->dtable);
+               misc += SIZE_IFNONZERO(clazz->vtable);
                misc += SIZE_IFNONZERO(CLASS_CONSTANTS(clazz)->data);
                misc += SIZE_IFNONZERO(CLASS_FIELDS(clazz));
                misc += SIZE_IFNONZERO(CLASS_STATICDATA(clazz));
@@ -571,10 +571,10 @@
        misc += SIZE_IFNONZERO(clazz);          /* myself */
        if (!CLASS_IS_PRIMITIVE(clazz)) {
-               /* For primitives, dtable is -1 and methods is the
+               /* For primitives, vtable is -1 and methods is the
                 * class of the corresponding array
                 */

Reply via email to